@@ -95,6 +95,20 @@ def delete_records():
     return data
 
 
+@applications.route("/modify_records/", methods=[POST])
+def modify_records():
+    """
+    修改research结果记录
+    :return:
+    """
+    data = json.loads(request.get_data())
+    c = ast.literal_eval(data["c"])
+    record = ResearchRecord(**c)
+    res = record.modify(data)
+    data = generate_result(data=str(res))
+    return data
+
+
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
     parser.add_argument('--port', type=int, default=8000, help="port number will be used to start")
