@@ -4,6 +4,7 @@
 # @FileName: research_util.py
 # @Software: PyCharm
 # @Email   ：liwudi@liwudi.fun
+import ast
 import sys
 import time
 from typing import Callable, Dict, Tuple
@@ -29,6 +30,9 @@ class ResearchRecord(object):
         :param db_conf:详见readme文件
         """
         super().__init__()
+        self.conn = None
+        self.cursor = None
+        self.ssl = None
         if len(db_conf) <= 0:
             log("需要配置字典", print_file=sys.stderr)
             return None
@@ -40,21 +44,17 @@ class ResearchRecord(object):
                 ssh_address_or_host=(db_conf.get("ssl_ip"), db_conf.get("ssl_port")),
                 ssh_username=db_conf.get("ssl_admin"),
                 ssh_password=db_conf.get("ssl_pwd"),
-                remote_bind_address=('localhost', db_conf["ssl_db_port"])
+                remote_bind_address=('localhost', db_conf.get("ssl_db_port"))
             )
             self.ssl.start()
-        else:
-            self.ssl = None
-
-        self.db_url = "127.0.0.1" if check_ssl else db_conf["db_url"]
-        self.db_username = db_conf["db_username"]
-        self.db_pass = db_conf["pass"]
-        self.port = self.ssl.local_bind_port if check_ssl else db_conf["port"]
+        self.db_url = "127.0.0.1" if check_ssl else db_conf.get("db_url")
+        self.db_username = db_conf.get("db_username")
+        self.db_pass = db_conf.get("pass")
+        self.port = self.ssl.local_bind_port if check_ssl else db_conf.get("port")
         self.db_database = db_conf.get("db_database") if db_conf.get("db_database") is not None else "research"
         self.db_table = db_conf.get("db_table") if db_conf.get("db_table") is not None else "record_result"
         self.db_type = "mysql"
-        self.conn = None
-        self.cursor = None
+
         self.ignore_error = db_conf.get("ignore_error") if db_conf.get("ignore_error") is not None else True
         try:
             self.create_db_conn()
@@ -182,7 +182,7 @@ class ResearchRecord(object):
         if self._execute(sql):
             return self.cursor.fetchall(), sum_page
         else:
-            return []
+            return [], 0
 
     def export(self, id_range: tuple or List = [-100], file_type: str = "csv", export_path: str = "",
                process: Callable[[List[str]], List] = None) -> bool:
@@ -386,6 +386,18 @@ class ResearchRecord(object):
             log("仅支持tuple和list", print_file=sys.stderr)
             return id_list, neg_id_min
 
+    def modify(self, data: Dict) -> bool:
+        try:
+            id = data["id"]
+        except Exception as e:
+            log("请提供id，{}".format(e))
+        other = data["other"]
+        sql = self.generate_sql({"other": other}, condition={("id", id): "="}, op_type=OP_TYPE[1])
+        if self._execute(sql):
+            return True
+        else:
+            return False
+
     def __del__(self):
         """
         关闭连接，不知道为什么调用的时候加（）会报错，比如self.ssl.stop（），会报错
